@@ -43,6 +43,7 @@
 #include "kernel-shared/print-tree.h"
 #include "kernel-shared/volumes.h"
 #include "kernel-shared/extent_io.h"
+#include "kernel-shared/compression.h"
 #include "common/utils.h"
 #include "common/help.h"
 #include "common/open-utils.h"
@@ -718,7 +719,7 @@ static int copy_file(struct btrfs_root *root, int fd, struct btrfs_key *key,
 				    struct btrfs_file_extent_item);
 		extent_type = btrfs_file_extent_type(leaf, fi);
 		compression = btrfs_file_extent_compression(leaf, fi);
-		if (compression >= BTRFS_COMPRESS_LAST) {
+		if (compression >= BTRFS_NR_COMPRESS_TYPES) {
 			warning("compression type %d not supported",
 				compression);
 			ret = -1;
@@ -1332,31 +1333,35 @@ static const char * const cmd_restore_usage[] = {
 	"btrfs restore [options] -l <device>",
 	"Try to restore files from a damaged filesystem (unmounted)",
 	"",
-	"  control:",
-	"       -D|--dry-run         dry run (only list files that would be recovered)",
-	"       -i|--ignore-errors   ignore errors",
-	"       -o|--overwrite       overwrite",
-	"  restoration:",
-	"       -m|--metadata        restore owner, mode and times",
-	"       -S|--symlink         restore symbolic links",
-	"       -s|--snapshots       get snapshots",
-	"       -x|--xattr           restore extended attributes",
-	"  filtering:",
-	"       --path-regex <regex>",
-	"                            restore only filenames matching regex,",
-	"                            you have to use following syntax (possibly quoted):",
-	"                            ^/(|home(|/username(|/Desktop(|/.*))))$",
-	"       -c                   ignore case (--path-regex only)",
-	"  analysis:",
-	"       -d                   find dir",
-	"       -l|--list-roots      list tree roots",
-	"  alternate starting point:",
-	"       -f <bytenr>          filesystem location",
-	"       -r|--root <rootid>   root objectid",
-	"       -t <bytenr>          tree location",
-	"       -u|--super <mirror>  super mirror",
-	"  other:",
-	"       -v|--verbose         deprecated, alias for global -v option",
+	"Control:",
+	OPTLINE("-D|--dry-run", "dry run (only list files that would be recovered)"),
+	OPTLINE("-i|--ignore-errors", "ignore errors"),
+	OPTLINE("-o|--overwrite", "overwrite"),
+	"",
+	"Restoration:",
+	OPTLINE("-m|--metadata", "restore owner, mode and times"),
+	OPTLINE("-S|--symlink", "restore symbolic links"),
+	OPTLINE("-s|--snapshots", "get snapshots"),
+	OPTLINE("-x|--xattr", "restore extended attributes"),
+	"",
+	"Filtering:",
+	OPTLINE("--path-regex <regex>", "restore only filenames matching regex, "
+		"you have to use following syntax (possibly quoted): "
+		"^/(|home(|/username(|/Desktop(|/.*))))$"),
+	OPTLINE("-c", "ignore case (--path-regex only)"),
+	"",
+	"Analysis:",
+	OPTLINE("-d", "find dir"),
+	OPTLINE("-l|--list-roots", "list tree roots"),
+	"",
+	"Alternate starting point:",
+	OPTLINE("-f <bytenr>", "filesystem location"),
+	OPTLINE("-r|--root <rootid>", "root objectid"),
+	OPTLINE("-t <bytenr>", "tree location"),
+	OPTLINE("-u|--super <mirror>", "super mirror"),
+	"",
+	"Other:",
+	OPTLINE("-v|--verbose", "deprecated, alias for global -v option"),
 	HELPINFO_INSERT_GLOBALS,
 	HELPINFO_INSERT_VERBOSE,
 	"",
@@ -1480,9 +1485,9 @@ static int cmd_restore(const struct cmd_struct *cmd, int argc, char **argv)
 	}
 
 	if (!list_roots && check_argc_min(argc - optind, 2))
-		usage(cmd);
+		usage(cmd, 1);
 	else if (list_roots && check_argc_min(argc - optind, 1))
-		usage(cmd);
+		usage(cmd, 1);
 
 	if (fs_location && root_objectid) {
 		error("can't use -f and -r at the same time");
