@@ -17,17 +17,14 @@
  */
 
 #include "kerncompat.h"
-
 #include <sys/ioctl.h>
 #include <sys/wait.h>
 #include <sys/stat.h>
-#include <sys/types.h>
 #include <sys/socket.h>
 #include <sys/un.h>
-#include <sys/syscall.h>
-#include <poll.h>
 #include <sys/file.h>
-#include <uuid/uuid.h>
+#include <sys/time.h>
+#include <poll.h>
 #include <fcntl.h>
 #include <unistd.h>
 #include <pthread.h>
@@ -35,16 +32,26 @@
 #include <signal.h>
 #include <stdarg.h>
 #include <limits.h>
-
-#include "kernel-shared/ctree.h"
-#include "ioctl.h"
-#include "common/utils.h"
+#include <dirent.h>
+#include <errno.h>
+#include <getopt.h>
+#include <stdbool.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <syscall.h>
+#include <time.h>
+#include <uuid/uuid.h>
+#include "kernel-lib/sizes.h"
 #include "kernel-shared/volumes.h"
-#include "kernel-shared/disk-io.h"
+#include "common/defs.h"
+#include "common/messages.h"
+#include "common/utils.h"
 #include "common/open-utils.h"
 #include "common/units.h"
-#include "cmds/commands.h"
 #include "common/help.h"
+#include "cmds/commands.h"
+#include "ioctl.h"
 
 static unsigned unit_mode = UNITS_DEFAULT;
 
@@ -114,26 +121,26 @@ struct scrub_fs_stat {
 
 static void print_scrub_full(struct btrfs_scrub_progress *sp)
 {
-	printf("\tdata_extents_scrubbed: %lld\n", sp->data_extents_scrubbed);
-	printf("\ttree_extents_scrubbed: %lld\n", sp->tree_extents_scrubbed);
-	printf("\tdata_bytes_scrubbed: %lld\n", sp->data_bytes_scrubbed);
-	printf("\ttree_bytes_scrubbed: %lld\n", sp->tree_bytes_scrubbed);
-	printf("\tread_errors: %lld\n", sp->read_errors);
-	printf("\tcsum_errors: %lld\n", sp->csum_errors);
-	printf("\tverify_errors: %lld\n", sp->verify_errors);
-	printf("\tno_csum: %lld\n", sp->no_csum);
-	printf("\tcsum_discards: %lld\n", sp->csum_discards);
-	printf("\tsuper_errors: %lld\n", sp->super_errors);
-	printf("\tmalloc_errors: %lld\n", sp->malloc_errors);
-	printf("\tuncorrectable_errors: %lld\n", sp->uncorrectable_errors);
-	printf("\tunverified_errors: %lld\n", sp->unverified_errors);
-	printf("\tcorrected_errors: %lld\n", sp->corrected_errors);
-	printf("\tlast_physical: %lld\n", sp->last_physical);
+	pr_verbose(LOG_DEFAULT, "\tdata_extents_scrubbed: %lld\n", sp->data_extents_scrubbed);
+	pr_verbose(LOG_DEFAULT, "\ttree_extents_scrubbed: %lld\n", sp->tree_extents_scrubbed);
+	pr_verbose(LOG_DEFAULT, "\tdata_bytes_scrubbed: %lld\n", sp->data_bytes_scrubbed);
+	pr_verbose(LOG_DEFAULT, "\ttree_bytes_scrubbed: %lld\n", sp->tree_bytes_scrubbed);
+	pr_verbose(LOG_DEFAULT, "\tread_errors: %lld\n", sp->read_errors);
+	pr_verbose(LOG_DEFAULT, "\tcsum_errors: %lld\n", sp->csum_errors);
+	pr_verbose(LOG_DEFAULT, "\tverify_errors: %lld\n", sp->verify_errors);
+	pr_verbose(LOG_DEFAULT, "\tno_csum: %lld\n", sp->no_csum);
+	pr_verbose(LOG_DEFAULT, "\tcsum_discards: %lld\n", sp->csum_discards);
+	pr_verbose(LOG_DEFAULT, "\tsuper_errors: %lld\n", sp->super_errors);
+	pr_verbose(LOG_DEFAULT, "\tmalloc_errors: %lld\n", sp->malloc_errors);
+	pr_verbose(LOG_DEFAULT, "\tuncorrectable_errors: %lld\n", sp->uncorrectable_errors);
+	pr_verbose(LOG_DEFAULT, "\tunverified_errors: %lld\n", sp->unverified_errors);
+	pr_verbose(LOG_DEFAULT, "\tcorrected_errors: %lld\n", sp->corrected_errors);
+	pr_verbose(LOG_DEFAULT, "\tlast_physical: %lld\n", sp->last_physical);
 }
 
 #define PRINT_SCRUB_ERROR(test, desc) do {	\
 	if (test)				\
-		printf(" %s=%llu", desc, test);	\
+		pr_verbose(LOG_DEFAULT, " %s=%llu", desc, test);	\
 } while (0)
 
 static void print_scrub_summary(struct btrfs_scrub_progress *p, struct scrub_stats *s,
@@ -160,7 +167,7 @@ static void print_scrub_summary(struct btrfs_scrub_progress *p, struct scrub_sta
 	err_cnt2 = p->corrected_errors + p->uncorrectable_errors;
 
 	if (p->malloc_errors)
-		printf("*** WARNING: memory allocation failed while scrubbing. "
+		pr_verbose(LOG_DEFAULT, "*** WARNING: memory allocation failed while scrubbing. "
 		       "results may be inaccurate\n");
 
 	if (s->in_progress) {
@@ -173,16 +180,16 @@ static void print_scrub_summary(struct btrfs_scrub_progress *p, struct scrub_sta
 		t[sizeof(t) - 1] = '\0';
 		strftime(t, sizeof(t), "%c", &tm);
 
-		printf("Time left:        %llu:%02llu:%02llu\n",
+		pr_verbose(LOG_DEFAULT, "Time left:        %llu:%02llu:%02llu\n",
 			sec_left / 3600, (sec_left / 60) % 60, sec_left % 60);
-		printf("ETA:              %s\n", t);
-		printf("Total to scrub:   %s\n",
+		pr_verbose(LOG_DEFAULT, "ETA:              %s\n", t);
+		pr_verbose(LOG_DEFAULT, "Total to scrub:   %s\n",
 			pretty_size_mode(bytes_total, unit_mode));
-		printf("Bytes scrubbed:   %s  (%.2f%%)\n",
+		pr_verbose(LOG_DEFAULT, "Bytes scrubbed:   %s  (%.2f%%)\n",
 			pretty_size_mode(bytes_scrubbed, unit_mode),
 			100.0 * bytes_scrubbed / bytes_total);
 	} else {
-		printf("Total to scrub:   %s\n",
+		pr_verbose(LOG_DEFAULT, "Total to scrub:   %s\n",
 			pretty_size_mode(bytes_total, unit_mode));
 	}
 	/*
@@ -190,25 +197,25 @@ static void print_scrub_summary(struct btrfs_scrub_progress *p, struct scrub_sta
 	 * by --raw, otherwise it's human readable
 	 */
 	if (unit_mode == UNITS_RAW) {
-		printf("Rate:             %s/s\n",
+		pr_verbose(LOG_DEFAULT, "Rate:             %s/s\n",
 			pretty_size_mode(bytes_per_sec, UNITS_RAW));
 	} else {
-		printf("Rate:             %s/s\n",
+		pr_verbose(LOG_DEFAULT, "Rate:             %s/s\n",
 			pretty_size(bytes_per_sec));
 	}
 
-	printf("Error summary:   ");
+	pr_verbose(LOG_DEFAULT, "Error summary:   ");
 	if (err_cnt || err_cnt2) {
 		PRINT_SCRUB_ERROR(p->read_errors, "read");
 		PRINT_SCRUB_ERROR(p->super_errors, "super");
 		PRINT_SCRUB_ERROR(p->verify_errors, "verify");
 		PRINT_SCRUB_ERROR(p->csum_errors, "csum");
-		printf("\n");
-		printf("  Corrected:      %llu\n", p->corrected_errors);
-		printf("  Uncorrectable:  %llu\n", p->uncorrectable_errors);
-		printf("  Unverified:     %llu\n", p->unverified_errors);
+		pr_verbose(LOG_DEFAULT, "\n");
+		pr_verbose(LOG_DEFAULT, "  Corrected:      %llu\n", p->corrected_errors);
+		pr_verbose(LOG_DEFAULT, "  Uncorrectable:  %llu\n", p->uncorrectable_errors);
+		pr_verbose(LOG_DEFAULT, "  Unverified:     %llu\n", p->unverified_errors);
 	} else {
-		printf(" no errors found\n");
+		pr_verbose(LOG_DEFAULT, " no errors found\n");
 	}
 }
 
@@ -280,37 +287,37 @@ static void _print_scrub_ss(struct scrub_stats *ss)
 	unsigned hours;
 
 	if (!ss || !ss->t_start) {
-		printf("\tno stats available\n");
+		pr_verbose(LOG_DEFAULT, "\tno stats available\n");
 		return;
 	}
 	if (ss->t_resumed) {
 		localtime_r(&ss->t_resumed, &tm);
 		strftime(t, sizeof(t), "%c", &tm);
 		t[sizeof(t) - 1] = '\0';
-		printf("Scrub resumed:    %s\n", t);
+		pr_verbose(LOG_DEFAULT, "Scrub resumed:    %s\n", t);
 	} else {
 		localtime_r(&ss->t_start, &tm);
 		strftime(t, sizeof(t), "%c", &tm);
 		t[sizeof(t) - 1] = '\0';
-		printf("Scrub started:    %s\n", t);
+		pr_verbose(LOG_DEFAULT, "Scrub started:    %s\n", t);
 	}
 
 	seconds = ss->duration;
 	hours = ss->duration / (60 * 60);
 	gmtime_r(&seconds, &tm);
 	strftime(t, sizeof(t), "%M:%S", &tm);
-	printf("Status:           %s\n",
+	pr_verbose(LOG_DEFAULT, "Status:           %s\n",
 			(ss->in_progress ? "running" :
 			 (ss->canceled ? "aborted" :
 			  (ss->finished ? "finished" : "interrupted"))));
-	printf("Duration:         %u:%s\n", hours, t);
+	pr_verbose(LOG_DEFAULT, "Duration:         %u:%s\n", hours, t);
 }
 
 static void print_scrub_dev(struct btrfs_ioctl_dev_info_args *di,
 				struct btrfs_scrub_progress *p, int raw,
 				const char *append, struct scrub_stats *ss)
 {
-	printf("\nScrub device %s (id %llu) %s\n", di->path, di->devid,
+	pr_verbose(LOG_DEFAULT, "\nScrub device %s (id %llu) %s\n", di->path, di->devid,
 	       append ? append : "");
 
 	_print_scrub_ss(ss);
@@ -519,7 +526,7 @@ static struct scrub_file_record **scrub_read_file(int fd, int report_errors)
 	int i = 0;
 	int j;
 	int ret;
-	int eof = 0;
+	bool eof = false;
 	int lineno = 0;
 	u64 version;
 	char empty_uuid[BTRFS_FSID_SIZE] = {0};
@@ -535,7 +542,7 @@ again:
 		memmove(l, l + i, old_avail);
 	avail = read(fd, l + old_avail, sizeof(l) - old_avail);
 	if (avail == 0)
-		eof = 1;
+		eof = true;
 	if (avail == 0 && old_avail == 0) {
 		if (curr >= 0 &&
 		    memcmp(p[curr]->fsid, empty_uuid, BTRFS_FSID_SIZE) == 0) {
@@ -595,7 +602,7 @@ again:
 			memset(p[curr], 0, sizeof(**p));
 			p[curr + 1] = NULL;
 			++state;
-			/* fall through */
+			fallthrough;
 		case 2: /* start of line, skip space */
 			while (isspace(l[i]) && i < avail) {
 				if (l[i] == '\n')
@@ -606,7 +613,7 @@ again:
 			    (!eof && !memchr(l + i, '\n', avail - i)))
 				goto again;
 			++state;
-			/* fall through */
+			fallthrough;
 		case 3: /* read fsid */
 			if (i == avail)
 				continue;
@@ -622,7 +629,7 @@ again:
 				_SCRUB_INVALID;
 			i += j + 1;
 			++state;
-			/* fall through */
+			fallthrough;
 		case 4: /* read dev id */
 			for (j = 0; isdigit(l[i + j]) && i+j < avail; ++j)
 				;
@@ -631,7 +638,7 @@ again:
 			p[curr]->devid = atoll(&l[i]);
 			i += j + 1;
 			++state;
-			/* fall through */
+			fallthrough;
 		case 5: /* read key/value pair */
 			ret = 0;
 			_SCRUB_KVREAD(ret, &i, data_extents_scrubbed, avail, l,
@@ -675,7 +682,7 @@ again:
 			if (ret != 1)
 				_SCRUB_INVALID;
 			++state;
-			/* fall through */
+			fallthrough;
 		case 6: /* after number */
 			if (l[i] == '|')
 				state = 5;
@@ -1152,19 +1159,18 @@ static int scrub_start(const struct cmd_struct *cmd, int argc, char **argv,
 	int err = 0;
 	int e_uncorrectable = 0;
 	int e_correctable = 0;
-	int print_raw = 0;
+	bool print_raw = false;
 	char *path;
-	int do_background = 1;
-	int do_wait = 0;
-	int do_print = 0;
+	bool do_background = true;
+	bool do_wait = false;
+	bool do_print = false;
 	int do_quiet = !bconf.verbose; /*Read the global quiet option if set*/
-	int do_record = 1;
-	int readonly = 0;
-	int do_stats_per_dev = 0;
+	bool do_record = true;
+	bool readonly = false;
+	bool do_stats_per_dev = false;
 	int ioprio_class = IOPRIO_CLASS_IDLE;
 	int ioprio_classdata = 0;
 	int n_start = 0;
-	int n_skip = 0;
 	int n_resume = 0;
 	struct btrfs_ioctl_fs_info_args fi_args;
 	struct btrfs_ioctl_dev_info_args *di_args = NULL;
@@ -1186,28 +1192,28 @@ static int scrub_start(const struct cmd_struct *cmd, int argc, char **argv,
 	void *terr;
 	u64 devid;
 	DIR *dirstream = NULL;
-	int force = 0;
-	int nothing_to_resume = 0;
+	bool force = false;
+	bool nothing_to_resume = false;
 
 	while ((c = getopt(argc, argv, "BdqrRc:n:f")) != -1) {
 		switch (c) {
 		case 'B':
-			do_background = 0;
-			do_wait = 1;
-			do_print = 1;
+			do_background = false;
+			do_wait = true;
+			do_print = true;
 			break;
 		case 'd':
-			do_stats_per_dev = 1;
+			do_stats_per_dev = true;
 			break;
 		case 'q':
 			bconf_be_quiet();
 			do_quiet = !bconf.verbose;
 			break;
 		case 'r':
-			readonly = 1;
+			readonly = true;
 			break;
 		case 'R':
-			print_raw = 1;
+			print_raw = true;
 			break;
 		case 'c':
 			ioprio_class = (int)strtol(optarg, NULL, 10);
@@ -1216,7 +1222,7 @@ static int scrub_start(const struct cmd_struct *cmd, int argc, char **argv,
 			ioprio_classdata = (int)strtol(optarg, NULL, 10);
 			break;
 		case 'f':
-			force = 1;
+			force = true;
 			break;
 		default:
 			usage_unknown_option(cmd, argv);
@@ -1230,13 +1236,13 @@ static int scrub_start(const struct cmd_struct *cmd, int argc, char **argv,
 
 	spc.progress = NULL;
 	if (do_quiet && do_print)
-		do_print = 0;
+		do_print = false;
 
 	if (mkdir_p(datafile)) {
 		warning_on(!do_quiet,
     "cannot create scrub data file, mkdir %s failed: %m. Status recording disabled",
 			datafile);
-		do_record = 0;
+		do_record = false;
 	}
 	free(datafile);
 
@@ -1279,7 +1285,7 @@ static int scrub_start(const struct cmd_struct *cmd, int argc, char **argv,
 	 * canceled=0, finished=0 but no scrub is running.
 	 */
 	if (!is_scrub_running_in_kernel(fdmnt, di_args, fi_args.num_devices))
-		force = 1;
+		force = true;
 
 	/*
 	 * check whether any involved device is already busy running a
@@ -1330,7 +1336,6 @@ static int scrub_start(const struct cmd_struct *cmd, int argc, char **argv,
 			sp[i].scrub_args.start = last_scrub->p.last_physical;
 			sp[i].resumed = last_scrub;
 		} else if (resume) {
-			++n_skip;
 			sp[i].skip = 1;
 			sp[i].resumed = last_scrub;
 			continue;
@@ -1347,10 +1352,10 @@ static int scrub_start(const struct cmd_struct *cmd, int argc, char **argv,
 	}
 
 	if (!n_start && !n_resume) {
-		pr_verbose(MUST_LOG,
+		pr_verbose(LOG_DEFAULT,
 			   "scrub: nothing to resume for %s, fsid %s\n",
 			   path, fsid);
-		nothing_to_resume = 1;
+		nothing_to_resume = true;
 		goto out;
 	}
 
@@ -1405,7 +1410,7 @@ static int scrub_start(const struct cmd_struct *cmd, int argc, char **argv,
 			errno = -ret;
 			warning_on(!do_quiet,
    "failed to write the progress status file: %m. Status recording disabled");
-			do_record = 0;
+			do_record = false;
 		}
 	}
 
@@ -1420,7 +1425,7 @@ static int scrub_start(const struct cmd_struct *cmd, int argc, char **argv,
 		if (pid) {
 			int stat;
 			scrub_handle_sigint_parent();
-			pr_verbose(MUST_LOG,
+			pr_verbose(LOG_DEFAULT,
 				   "scrub %s on %s, fsid %s (pid=%d)\n",
 				   n_start ? "started" : "resumed",
 				   path, fsid, pid);
@@ -1555,7 +1560,7 @@ static int scrub_start(const struct cmd_struct *cmd, int argc, char **argv,
 			total_bytes_used += di_args[i].bytes_used;
 		}
 		if (!do_stats_per_dev) {
-			printf("scrub %s for %s\n", append, fsid);
+			pr_verbose(LOG_DEFAULT, "scrub %s for %s\n", append, fsid);
 			print_fs_stat(&fs_stat, print_raw, total_bytes_used);
 		}
 	}
@@ -1619,16 +1624,14 @@ static const char * const cmd_scrub_start_usage[] = {
 	"btrfs scrub start [-BdqrRf] [-c ioprio_class -n ioprio_classdata] <path>|<device>",
 	"Start a new scrub. If a scrub is already running, the new one fails.",
 	"",
-	"-B     do not background",
-	"-d     stats per device (-B only)",
-	"-q     be quiet",
-	"-r     read only mode",
-	"-R     raw print mode, print full data instead of summary",
-	"-c     set ioprio class (see ionice(1) manpage)",
-	"-n     set ioprio classdata (see ionice(1) manpage)",
-	"-f     force starting new scrub even if a scrub is already running",
-	"       this is useful when scrub stats record file is damaged",
-	"-q     deprecated, alias for global -q option",
+	OPTLINE("-B", "do not background"),
+	OPTLINE("-d", "stats per device (-B only)"),
+	OPTLINE("-r", "read only mode"),
+	OPTLINE("-R", "raw print mode, print full data instead of summary"),
+	OPTLINE("-c", "set ioprio class (see ionice(1) manpage)"),
+	OPTLINE("-n", "set ioprio classdata (see ionice(1) manpage)"),
+	OPTLINE("-f", "force starting new scrub even if a scrub is already running this is useful when scrub stats record file is damaged"),
+	OPTLINE("-q", "deprecated, alias for global -q option"),
 	HELPINFO_INSERT_GLOBALS,
 	HELPINFO_INSERT_QUIET,
 	NULL
@@ -1681,7 +1684,7 @@ static int cmd_scrub_cancel(const struct cmd_struct *cmd, int argc, char **argv)
 	}
 
 	ret = 0;
-	pr_verbose(MUST_LOG, "scrub cancelled\n");
+	pr_verbose(LOG_DEFAULT, "scrub cancelled\n");
 
 out:
 	close_file_or_dir(fdmnt, dirstream);
@@ -1693,13 +1696,13 @@ static const char * const cmd_scrub_resume_usage[] = {
 	"btrfs scrub resume [-BdqrR] [-c ioprio_class -n ioprio_classdata] <path>|<device>",
 	"Resume previously canceled or interrupted scrub",
 	"",
-	"-B     do not background",
-	"-d     stats per device (-B only)",
-	"-r     read only mode",
-	"-R     raw print mode, print full data instead of summary",
-	"-c     set ioprio class (see ionice(1) manpage)",
-	"-n     set ioprio classdata (see ionice(1) manpage)",
-	"-q     deprecated, alias for global -q option",
+	OPTLINE("-B", "do not background"),
+	OPTLINE("-d", "stats per device (-B only)"),
+	OPTLINE("-r", "read only mode"),
+	OPTLINE("-R", "raw print mode, print full data instead of summary"),
+	OPTLINE("-c", "set ioprio class (see ionice(1) manpage)"),
+	OPTLINE("-n", "set ioprio classdata (see ionice(1) manpage)"),
+	OPTLINE("-q", "deprecated, alias for global -q option"),
 	HELPINFO_INSERT_GLOBALS,
 	HELPINFO_INSERT_QUIET,
 	NULL
@@ -1715,8 +1718,8 @@ static const char * const cmd_scrub_status_usage[] = {
 	"btrfs scrub status [-dR] <path>|<device>",
 	"Show status of running or finished scrub",
 	"",
-	"-d                 stats per device",
-	"-R                 print raw stats",
+	OPTLINE("-d", "stats per device"),
+	OPTLINE("-R", "print raw stats"),
 	HELPINFO_UNITS_LONG,
 	NULL
 };
@@ -1737,8 +1740,8 @@ static int cmd_scrub_status(const struct cmd_struct *cmd, int argc, char **argv)
 	int ret;
 	int i;
 	int fdmnt;
-	int print_raw = 0;
-	int do_stats_per_dev = 0;
+	bool print_raw = false;
+	bool do_stats_per_dev = false;
 	int c;
 	char fsid[BTRFS_UUID_UNPARSED_SIZE];
 	int fdres = -1;
@@ -1751,10 +1754,10 @@ static int cmd_scrub_status(const struct cmd_struct *cmd, int argc, char **argv)
 	while ((c = getopt(argc, argv, "dR")) != -1) {
 		switch (c) {
 		case 'd':
-			do_stats_per_dev = 1;
+			do_stats_per_dev = true;
 			break;
 		case 'R':
-			print_raw = 1;
+			print_raw = true;
 			break;
 		default:
 			usage_unknown_option(cmd, argv);
@@ -1823,7 +1826,7 @@ static int cmd_scrub_status(const struct cmd_struct *cmd, int argc, char **argv)
 	}
 	in_progress = is_scrub_running_in_kernel(fdmnt, di_args, fi_args.num_devices);
 
-	printf("UUID:             %s\n", fsid);
+	pr_verbose(LOG_DEFAULT, "UUID:             %s\n", fsid);
 
 	if (do_stats_per_dev) {
 		for (i = 0; i < fi_args.num_devices; ++i) {
