@@ -42,43 +42,39 @@
  * - uppercase for filters and sort options
  * - lowercase for enabling specific items in the output
  */
-static const char * const cmd_subvol_list_usage[] = {
+static const char * const cmd_subvolume_list_usage[] = {
 	"btrfs subvolume list [options] <path>",
 	"List subvolumes and snapshots in the filesystem.",
 	"",
 	"Path filtering:",
-	"-o           print only subvolumes below specified path",
-	"-a           print all the subvolumes in the filesystem and",
-	"             distinguish absolute and relative path with respect",
-	"             to the given <path>",
+	OPTLINE("-o", "print only subvolumes below specified path"),
+	OPTLINE("-a", "print all the subvolumes in the filesystem and "
+		"distinguish absolute and relative path with respect to the given <path>"),
 	"",
 	"Field selection:",
-	"-p           print parent ID",
-	"-c           print the ogeneration of the subvolume",
-	"-g           print the generation of the subvolume",
-	"-u           print the uuid of subvolumes (and snapshots)",
-	"-q           print the parent uuid of the snapshots",
-	"-R           print the uuid of the received snapshots",
+	OPTLINE("-p", "print parent ID"),
+	OPTLINE("-c", "print the ogeneration of the subvolume"),
+	OPTLINE("-g", "print the generation of the subvolume"),
+	OPTLINE("-u", "print the uuid of subvolumes (and snapshots)"),
+	OPTLINE("-q", "print the parent uuid of the snapshots"),
+	OPTLINE("-R", "print the uuid of the received snapshots"),
 	"",
 	"Type filtering:",
-	"-s           list only snapshots",
-	"-r           list readonly subvolumes (including snapshots)",
-	"-d           list deleted subvolumes that are not yet cleaned",
+	OPTLINE("-s", "list only snapshots"),
+	OPTLINE("-r", "list readonly subvolumes (including snapshots)"),
+	OPTLINE("-d", "list deleted subvolumes that are not yet cleaned"),
 	"",
 	"Other:",
-	"-t           print the result as a table",
+	OPTLINE("-t", "print the result as a table"),
 	"",
 	"Sorting:",
-	"-G [+|-]value",
-	"             filter the subvolumes by generation",
-	"             (+value: >= value; -value: <= value; value: = value)",
-	"-C [+|-]value",
-	"             filter the subvolumes by ogeneration",
-	"             (+value: >= value; -value: <= value; value: = value)",
-	"--sort=gen,ogen,rootid,path",
-	"             list the subvolume in order of gen, ogen, rootid or path",
-	"             you also can add '+' or '-' in front of each items.",
-	"             (+:ascending, -:descending, ascending default)",
+	OPTLINE("-G [+|-]value", "filter the subvolumes by generation "
+		"(+value: >= value; -value: <= value; value: = value)"),
+	OPTLINE("-C [+|-]value", "filter the subvolumes by ogeneration "
+		"(+value: >= value; -value: <= value; value: = value)"),
+	OPTLINE("--sort=gen,ogen,rootid,path", "list the subvolume in order of gen, ogen, rootid or path "
+		"you also can add '+' or '-' in front of each items. "
+		"(+:ascending, -:descending, ascending default)"),
 	NULL,
 };
 
@@ -870,14 +866,21 @@ static int list_subvol_search(int fd, struct rb_root *root_lookup)
 				ri = (struct btrfs_root_item *)(args.buf + off);
 				gen = btrfs_root_generation(ri);
 				flags = btrfs_root_flags(ri);
-				if(sh.len >
-				   sizeof(struct btrfs_root_item_v0)) {
+				if(sh.len >= sizeof(struct btrfs_root_item)) {
+					/*
+					 * The new full btrfs_root_item with
+					 * timestamp and UUID.
+					 */
 					otime = btrfs_stack_timespec_sec(&ri->otime);
 					ogen = btrfs_root_otransid(ri);
 					memcpy(uuid, ri->uuid, BTRFS_UUID_SIZE);
 					memcpy(puuid, ri->parent_uuid, BTRFS_UUID_SIZE);
 					memcpy(ruuid, ri->received_uuid, BTRFS_UUID_SIZE);
 				} else {
+					/*
+					 * The old v0 root item, which doesn't
+					 * have timestamp nor UUID.
+					 */
 					otime = 0;
 					ogen = 0;
 					memset(uuid, 0, BTRFS_UUID_SIZE);
@@ -1482,7 +1485,7 @@ static struct btrfs_list_comparer_set *btrfs_list_alloc_comparer_set(void)
 	return set;
 }
 
-static int cmd_subvol_list(const struct cmd_struct *cmd, int argc, char **argv)
+static int cmd_subvolume_list(const struct cmd_struct *cmd, int argc, char **argv)
 {
 	struct btrfs_list_filter_set *filter_set;
 	struct btrfs_list_comparer_set *comparer_set;
@@ -1638,7 +1641,7 @@ out:
 	if (comparer_set)
 		free(comparer_set);
 	if (uerr)
-		usage(cmd);
+		usage(cmd, 1);
 	return !!ret;
 }
-DEFINE_SIMPLE_COMMAND(subvol_list, "list");
+DEFINE_SIMPLE_COMMAND(subvolume_list, "list");
